@@ -10,7 +10,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: class.uiconfig.inc.php,v 1.27 2006/12/19 14:01:10 skwashd Exp $ */
+  /* $Id: class.uiconfig.inc.php,v 1.28 2007/02/21 10:30:32 sigurdne Exp $ */
 
 	class uiconfig
 	{
@@ -168,7 +168,7 @@
 			(
 				'action_url'	=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=>'admin.uiconfig.index', 'appname'=> $appname) ),
 				'lang_cancel'	=> lang('cancel'),
-				'lang_save'		=> lang('save'),
+				'lang_submit'	=> lang('save'),
 				'title'			=> lang('Site Configuration'),
 			));
 
