@@ -6,7 +6,7 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage accounts
-	* @version $Id: class.acl.inc.php,v 1.2 2007/02/06 12:42:17 sigurdne Exp $
+	* @version $Id: class.acl.inc.php,v 1.4 2007/02/24 20:32:46 sigurdne Exp $
 	*/
 
 	/**
@@ -584,12 +584,11 @@
 		{
 			$rights = $this->check_brutto($location, $required, $appname, false, $type=0);
 			$mask = $this->check_brutto($location, $required, $appname, false, $type=1);
-			
+
 			if ( $mask > 0 && $rights > 0 )
 			{
-				unset($rights);
+				$rights = false;
 			}
-
 			return $rights;
 		}
 
@@ -723,7 +722,7 @@
 				}
 				else
 				{
-					return False;
+//					return False; //Sigurd: I think this is wrong
 				}
 			}
 			return $locations;
