@@ -8,7 +8,7 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage utilities
-	* @version $Id: functions.inc.php,v 1.4 2007/02/07 13:43:37 sigurdne Exp $
+	* @version $Id: functions.inc.php,v 1.5 2007/02/25 16:13:08 sigurdne Exp $
 	*/
 	
 	
@@ -653,7 +653,7 @@
 		/*************************************************************************\
 		* These lines load up the themes  .16-compability                          *
 		\*************************************************************************/
-		if (! $GLOBALS['phpgw_info']['user']['preferences']['common']['theme'])
+		if (!isset($GLOBALS['phpgw_info']['user']['preferences']['common']['theme']) || !$GLOBALS['phpgw_info']['user']['preferences']['common']['theme'])
 		{
 			if (@$GLOBALS['phpgw_info']['server']['template_set'] == 'user_choice')
 			{
