@@ -5,7 +5,7 @@
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage setup
-	* @version $Id: tables_update.inc.php,v 1.5 2007/02/07 21:46:44 sigurdne Exp $
+	* @version $Id: tables_update.inc.php,v 1.8 2007/02/27 12:30:33 sigurdne Exp $
 	* @internal $Source: /sources/fmsystem/phpgwapi/setup/tables_update.inc.php,v $
 	*/
 
@@ -1417,8 +1417,6 @@
 
 //----------- sync with 17
 
-
-
 	$test[] = '0.9.16.011';
 	function phpgwapi_upgrade0_9_16_011()
 	{
@@ -1534,15 +1532,6 @@
 				)
 		);
 
-/*
-		$GLOBALS['phpgw_setup']->oProc->AlterColumn('phpgw_acl','acl_type',array(
-			'type' => 'int',
-			'precision' => 2,
-			'default' => '0',
-			'nullable' => True
-		));
-*/
-
 		$GLOBALS['phpgw_setup']->oProc->CreateTable('phpgw_mail_handler',array(
 			'fd' => array(
 				'handler_id' => array('type' => 'auto','nullable' => False),
@@ -1565,4 +1554,51 @@
 		return $GLOBALS['setup_info']['phpgwapi']['currentver'];
 	}
 
+	/**
+	* Update phpgwapi version from 0.9.17.000 to 0.9.17.001
+	* Moved to utf-8 (have to dump database - create new with charset utf-8 - and then reload the dump.)
+	*/
+
+	$test[] = '0.9.17.000';
+	function phpgwapi_upgrade0_9_17_000()
+	{
+		$GLOBALS['phpgw_setup']->oProc->m_odb->Halt_On_Error='yes';
+		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
+
+		$GLOBALS['phpgw_setup']->oProc->query("UPDATE phpgw_acl set acl_type = 0 WHERE acl_type is NULL");
+		$GLOBALS['phpgw_setup']->oProc->AlterColumn('phpgw_acl','acl_type',array(
+			'type' => 'int',
+			'precision' => 2,
+			'default' => 0,
+			'nullable' => True
+		));
+
+		$metadata = $GLOBALS['phpgw_setup']->db->metadata('phpgw_log');
+		if(isset($metadata['log_user']))
+		{		
+			$GLOBALS['phpgw_setup']->oProc->DropColumn('phpgw_log',array(
+				'fd' => array(
+					'log_id' => array('type' => 'auto','precision' => '4','nullable' => False),
+					'log_date' => array('type' => 'timestamp','nullable' => False),
+					'log_account_id' => array('type' => 'int','precision' => '4','nullable' => False),
+					'log_account_lid' => array('type' => 'varchar','precision' => '25','nullable' => False),
+					'log_app' => array('type' => 'varchar','precision' => '25','nullable' => False),
+					'log_severity' => array('type' => 'char','precision' => '1','nullable' => False),
+					'log_file' => array('type' => 'varchar','precision' => '255','nullable' => False, 'default' => ''),
+					'log_line' => array('type' => 'int','precision' => '4','nullable' => False, 'default' => '0'),
+					'log_msg' => array('type' => 'text','nullable' => False)
+				),
+				'pk' => array('log_id'),
+				'fk' => array(),
+				'ix' => array(),
+				'uc' => array()
+			),'log_user');
+		}
+
+		if($GLOBALS['phpgw_setup']->oProc->m_odb->transaction_commit())
+		{
+			$GLOBALS['setup_info']['phpgwapi']['currentver'] = '0.9.17.001';		
+		}
+		return $GLOBALS['setup_info']['phpgwapi']['currentver'];
+	}
 ?>
