@@ -5,7 +5,7 @@
 	* @copyright Copyright (C) 2000-2006 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package preferences
-	* @version $Id: preferences.php,v 1.43 2006/12/20 08:34:42 sigurdne Exp $
+	* @version $Id: preferences.php,v 1.46 2007/02/26 19:26:58 sigurdne Exp $
 	*/
 
 	$GLOBALS['phpgw_info']['flags'] = array
@@ -151,7 +151,9 @@
 		
 		if ($GLOBALS['type'] == 'user')
 		{
-			$def_text = (!isset($GLOBALS['phpgw']->preferences->user[$_appname][$name]) || !$GLOBALS['phpgw']->preferences->user[$_appname][$name]) ? $GLOBALS['phpgw']->preferences->data[$_appname][$name] : $GLOBALS['phpgw']->preferences->default[$_appname][$name];
+			$def_text = (!isset($GLOBALS['phpgw']->preferences->user[$_appname][$name]) || !$GLOBALS['phpgw']->preferences->user[$_appname][$name]) ?
+			 (isset($GLOBALS['phpgw']->preferences->data[$_appname][$name])?$GLOBALS['phpgw']->preferences->data[$_appname][$name]:'') : 
+			 (isset($GLOBALS['phpgw']->preferences->default[$_appname][$name])?$GLOBALS['phpgw']->preferences->default[$_appname][$name]:'');
 
 			if (isset($notifys[$name]))	// translate the substitution names
 			{
@@ -371,7 +373,7 @@
 
 		if ($GLOBALS['type'] == 'user')
 		{
-			$def_text = !$GLOBALS['phpgw']->preferences->user[$_appname][$name] ? $GLOBALS['phpgw']->preferences->data[$_appname][$name] : $GLOBALS['phpgw']->preferences->default[$_appname][$name];
+			$def_text = !isset($GLOBALS['phpgw']->preferences->user[$_appname][$name]) || !$GLOBALS['phpgw']->preferences->user[$_appname][$name] ? (isset($GLOBALS['phpgw']->preferences->data[$_appname][$name])?$GLOBALS['phpgw']->preferences->data[$_appname][$name]:'') : (isset($GLOBALS['phpgw']->preferences->default[$_appname][$name])?$GLOBALS['phpgw']->preferences->default[$_appname][$name]:'');
 
 			if (isset($notifys[$name]))	// translate the substitution names
 			{
@@ -379,7 +381,7 @@
 			}
 			$def_text = $def_text != '' ? '<br><i><font size="-1"><b>'.lang('default').'</b>:<br>'.nl2br($def_text).'</font></i>' : '';
 		}
-		$t->set_var('row_value',"<textarea rows=\"$rows\" cols=\"$cols\" name=\"${GLOBALS['type']}[$name]\">".htmlentities($default)."</textarea>$def_text");
+		$t->set_var('row_value',"<textarea rows=\"$rows\" cols=\"$cols\" name=\"${GLOBALS['type']}[$name]\">".htmlentities($default,ENT_QUOTES,'UTF-8')."</textarea>$def_text");
 		$t->set_var('row_name',lang($label));
 		$GLOBALS['phpgw']->nextmatchs->template_alternate_row_class($t);
 
@@ -559,7 +561,7 @@
 			$GLOBALS['phpgw']->redirect_link('/preferences/index.php');
 		}
 		
-		if ($GLOBALS['type'] == 'user' && $_GET['appname'] == 'preferences' && $user['show_help'] != '')
+		if ($GLOBALS['type'] == 'user' && $_GET['appname'] == 'preferences' && (isset($user['show_help']) && $user['show_help'] != ''))
 		{
 			$show_help = $user['show_help'];	// use it, if admin changes his help-prefs
 		}
