@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage core
- 	* @version $Id: class.bocommon.inc.php,v 1.60 2007/01/26 14:53:46 sigurdne Exp $
+ 	* @version $Id: class.bocommon.inc.php,v 1.62 2007/02/19 21:02:41 sigurdne Exp $
 	*/
 
 	/**
@@ -962,6 +962,8 @@
 			$location_level 	= (isset($data['location_level'])?$data['location_level']:'');
 			$no_address 		= (isset($data['no_address'])?$data['no_address']:'');
 			$force_location		= (isset($data['force_location'])?$data['force_location']:'');
+			$cols_extra 		= array();
+			$cols_return_lookup	= array();
 
 			$soadmin_location	= CreateObject($this->currentapp.'.soadmin_location');
 			$location_types	= $soadmin_location->select_location_type();
@@ -1111,7 +1113,7 @@
 			$this->cols_extra		= $cols_extra;
 			$this->cols_return_lookup	= $cols_return_lookup;
 
-			$from .= " FROM $paranthesis $entity_table ";
+			$from = " FROM $paranthesis $entity_table ";
 
 			$sql = "SELECT $cols $from $joinmethod";
 
@@ -1327,7 +1329,7 @@
 
  			$filename= $GLOBALS['phpgw_info']['user']['account_lid'].'.xls';
 
-			$workbook	= CreateObject($this->currentapp.'.excel',"-");
+			$workbook	= CreateObject('phpgwapi.excel',"-");
 			$browser = CreateObject('phpgwapi.browser');
 			$browser->content_header($filename,'application/vnd.ms-excel');
 
@@ -1346,7 +1348,7 @@
 						if($input_type[$k]!='hidden')
 						{
 							$content[$j][$m]	= str_replace("\r\n"," ",$entry[$name[$k]]);
-							$worksheet1->write_string(0, $m, $descr[$k]);
+							$worksheet1->write_string(0, $m, $this->utf2ascii($descr[$k]));
 							$m++;
 						}
 					}
@@ -1359,7 +1361,7 @@
 					$line++;
 					for ($i=0; $i<count($row); $i++)
 					{
-						$worksheet1->write($line,$i,$row[$i]);
+						$worksheet1->write($line,$i, $this->utf2ascii($row[$i]));
 					}
 				}
 			}
@@ -1451,5 +1453,23 @@
 			
 			return $values;
 		}
+		
+		/**
+		* Converts ascii to utf-8
+		*
+		* @param string $text string
+		* @return string utf-8 encoded 
+		*/
+		function utf2ascii($text = '')
+		{	
+			if ($text == utf8_decode($text))
+			{
+				return $text;
+			}
+			else
+			{
+				return utf8_decode($text);
+			}
+		}
 	}
 ?>
