@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage location
- 	* @version $Id: class.bolocation.inc.php,v 1.30 2007/01/26 14:53:46 sigurdne Exp $
+ 	* @version $Id: class.bolocation.inc.php,v 1.31 2007/02/19 21:02:41 sigurdne Exp $
 	*/
 
 	/**
@@ -344,7 +344,7 @@
 					$location['location'][$i]['lookup_link']			= True;
 					$location['location'][$i]['readonly']				= True;
 					$location['location'][$i]['name']				= $fm_location_cols[$j]['input_text'];
-					$location['location'][$i]['value']				= $data['values'][$fm_location_cols[$j]['column_name']];
+					$location['location'][$i]['value']				= isset($data['values'][$fm_location_cols[$j]['column_name']]) ? $data['values'][$fm_location_cols[$j]['column_name']] : '';
 					$location['location'][$i]['statustext']				= lang('Klick this link to select') . ' ' . $location_types[($fm_location_cols[$j]['location_type']-1)]['name'];
 					$i++;
 
