@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage project
- 	* @version $Id: class.soproject.inc.php,v 1.39 2007/01/26 14:53:47 sigurdne Exp $
+ 	* @version $Id: class.soproject.inc.php,v 1.41 2007/02/20 22:22:20 sigurdne Exp $
 	*/
 
 	/**
@@ -138,7 +138,7 @@
 			{
 				$entity_table = 'fm_project';
 
-				$cols .= $entity_table . '.location_code';
+				$cols = $entity_table . '.location_code';
 				$cols_return[] = 'location_code';
 
 				$cols .= ",$entity_table.id as project_id";
@@ -171,8 +171,8 @@
 
 				$cols.= ",$entity_table.user_id";
 
-				$joinmethod .= " $this->join  phpgw_accounts ON ($entity_table.coordinator = phpgw_accounts.account_id))";
-				$paranthesis .='(';
+				$joinmethod = " $this->join  phpgw_accounts ON ($entity_table.coordinator = phpgw_accounts.account_id))";
+				$paranthesis ='(';
 
 				//----- wo_hour_status
 
@@ -385,6 +385,7 @@
 
 			$this->db->query($sql,__LINE__,__FILE__);
 
+			$last_type = false;
 			$i=-1;
 			while ($this->db->next_record())
 			{
