@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage project
- 	* @version $Id: class.uiproject.inc.php,v 1.49 2007/01/26 14:53:47 sigurdne Exp $
+ 	* @version $Id: class.uiproject.inc.php,v 1.51 2007/02/20 22:22:20 sigurdne Exp $
 	*/
 
 	/**
@@ -146,8 +146,7 @@
 					{
 						if($uicols['input_type'][$k]=='text')
 						{
-
-							if($project_entry['query_location'][$uicols['name'][$k]])
+							if(isset($project_entry['query_location'][$uicols['name'][$k]]) && $project_entry['query_location'][$uicols['name'][$k]])
 							{
 								$content[$j]['row'][]= array(
 									'statustext' => lang('search'),
@@ -585,7 +584,7 @@
 				$origin_id	= $values['origin_id'];
 			}
 
-			if($origin)
+			if(isset($origin) && $origin)
 			{
 				unset($values['origin']);
 				unset($values['origin_id']);
@@ -892,7 +891,7 @@
 				$supervisor_email = $prefs['email'];
 			}
 
-			if(!$values['start_date'])
+			if(!isset($values['start_date']) || !$values['start_date'])
 			{
 				$values['start_date'] = $GLOBALS['phpgw']->common->show_date(mktime(0,0,0,date("m"),date("d"),date("Y")),$GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
 			}
@@ -949,7 +948,7 @@
 			(
 				'msgbox_data'					=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
 
-				'value_origin'					=> $values['origin'],
+				'value_origin'					=> isset($values['origin']) ? $values['origin'] : '',
 				'value_origin_type'				=> (isset($origin)?$origin:''),
 				'value_origin_id'				=> (isset($origin_id)?$origin_id:''),
 				'selected_request'				=> (isset($selected_request)?$selected_request:''),
@@ -982,7 +981,7 @@
 
 				'lang_end_date_statustext'			=> lang('Select the estimated end date for the Project'),
 				'lang_end_date'					=> lang('Project end date'),
-				'value_end_date'				=> $values['end_date'],
+				'value_end_date'				=> isset($values['end_date']) ? $values['end_date'] : '' ,
 
 				'lang_copy_project'				=> lang('Copy project ?'),
 				'lang_copy_project_statustext'			=> lang('Choose Copy Project to copy this project to a new project'),
@@ -1187,7 +1186,7 @@
 						'tenant'	=> $values['location_data']['tenant_id'],
 						'lookup_type'	=> 'view',
 						'lookup_entity'	=> $this->bocommon->get_lookup_entity('project'),
-						'entity_data'	=> $values['p']
+						'entity_data'	=> isset($values['p'])?$values['p']:''
 						));
 
 			if($values['contact_phone'])
@@ -1240,8 +1239,8 @@
 				'msgbox_data'				=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
 
 				'value_origin'				=> $values['origin'],
-				'value_origin_type'			=> $origin,
-				'value_origin_id'			=> $origin_id,
+			//	'value_origin_type'			=> $origin,
+			//	'value_origin_id'			=> $origin_id,
 
 				'table_header_workorder_budget'		=> $table_header_workorder_budget,
 				'lang_no_workorders'			=> lang('No workorder budget'),
@@ -1258,7 +1257,7 @@
 				'value_end_date'			=> $values['end_date'],
 
 				'lang_charge_tenant'			=> lang('Charge tenant'),
-				'charge_tenant'				=> $values['charge_tenant'],
+				'charge_tenant'				=> isset($values['charge_tenant'])?$values['charge_tenant']:'',
 
 				'lang_power_meter'			=> lang('Power meter'),
 				'value_power_meter'			=> $values['power_meter'],
@@ -1271,10 +1270,10 @@
 				'lang_reserve_statustext'		=> lang('Enter the reserve'),
 
 				'lang_reserve_remainder'		=> lang('reserve remainder'),
-				'value_reserve_remainder'		=> $reserve_remainder,
-				'value_reserve_remainder_percent'	=> $remainder_percent,
+				'value_reserve_remainder'		=> isset($reserve_remainder)?$reserve_remainder:'',
+				'value_reserve_remainder_percent'	=> isset($remainder_percent)?$remainder_percent:'',
 
-				'vendor_data'				=> $vendor_data,
+				'vendor_data'				=> isset($vendor_data)?$vendor_data:'',
 				'location_data'				=> $location_data,
 				'location_type'				=> 'view',
 				'done_action'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiproject.index')),
