@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage helpdesk
- 	* @version $Id: class.uitts.inc.php,v 1.54 2007/01/26 14:53:47 sigurdne Exp $
+ 	* @version $Id: class.uitts.inc.php,v 1.55 2007/02/20 22:22:20 sigurdne Exp $
 	*/
 
 	/**
@@ -1591,7 +1591,7 @@
 						$entity_id	= $type[1];
 						$cat_id		= $type[2];
 
-						if(!is_object($boadmin_entity))
+						if(!isset($boadmin_entity) || !is_object($boadmin_entity))
 						{
 							$boadmin_entity	= CreateObject($this->currentapp.'.boadmin_entity');
 						}
@@ -1684,7 +1684,7 @@
 				'lang_assignedfrom'			=> lang('Assigned from'),
 				'value_assignedfrom'			=> $ticket['user_name'],
 				'lang_assignedto'			=> lang('Assigned to'),
-				'value_assignedto'			=> $ticket['assignedto_name'],
+				'value_assignedto'			=> isset($ticket['assignedto_name'])?$ticket['assignedto_name']:'',
 
 				'lang_no_additional_notes'		=> lang('No additional notes'),
 				'lang_history'				=> lang('History'),
