@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package sms
 	* @subpackage sms
- 	* @version $Id: class.sms.inc.php,v 1.21 2006/12/27 10:39:15 sigurdne Exp $
+ 	* @version $Id: class.sms.inc.php,v 1.23 2007/02/26 22:21:07 sigurdne Exp $
 	*/
 
 	/**
@@ -19,24 +19,26 @@
 
 //	_debug_array ($GLOBALS['phpgw_info']['sms_config']);
 
-	$apps_path[base]	= PHPGW_SERVER_ROOT . SEP . 'sms';
-	$apps_path[libs]	= "$apps_path[base]/lib";
-	$apps_path[plug]	= "$apps_path[base]/inc/plugin";
-	$apps_path[inc]		= "$apps_path[base]/inc";
+	$apps_path['base']	= PHPGW_SERVER_ROOT . SEP . 'sms';
+	$apps_path['libs']	= $apps_path['base'] . SEP . 'lib';
+	$apps_path['plug']	= $apps_path['base'] . SEP . 'inc' . SEP . 'plugin';
+	$apps_path['inc']	= $apps_path['base'] . SEP . 'inc';
 	
 	// SMS command security parameter
-	$feat_command_path[bin]	= $apps_path[base]."/bin";
+	$feat_command_path['bin']	= $apps_path['base']."/bin";
 	$GLOBALS['phpgw_info']['sms_config']['common']['apps_path'] = $apps_path;
 	$GLOBALS['phpgw_info']['sms_config']['common']['feat_command_path'] = $feat_command_path;
 
-	if(!$GLOBALS['phpgw_info']['sms_config']['common']['gateway_module'])
+	if(!isset($GLOBALS['phpgw_info']['sms_config']['common']['gateway_module']) || !$GLOBALS['phpgw_info']['sms_config']['common']['gateway_module'])
 	{
-		include_once(PHPGW_APP_INC . SEP . 'config.php');
+		$path_to_sms = dirname(__FILE__);
+
+		include_once($path_to_sms . SEP . 'config.php');
 	}
 
-	if (file_exists($apps_path[inc] . SEP . 'plugin' . SEP . 'gateway' . SEP . $GLOBALS['phpgw_info']['sms_config']['common']['gateway_module']. "/fn.php"))
+	if (file_exists($apps_path['inc'] . SEP . 'plugin' . SEP . 'gateway' . SEP . $GLOBALS['phpgw_info']['sms_config']['common']['gateway_module']. "/fn.php"))
 	{
-		include_once($apps_path[inc] . SEP . 'plugin' . SEP . 'gateway' . SEP. $GLOBALS['phpgw_info']['sms_config']['common']['gateway_module']. "/fn.php");
+		include_once($apps_path['inc'] . SEP . 'plugin' . SEP . 'gateway' . SEP. $GLOBALS['phpgw_info']['sms_config']['common']['gateway_module']. "/fn.php");
 	}
 	else
 	{
